# Optimize

::: inspeqtor.optimize

::: inspeqtor.optimize.get_default_optimizer

::: inspeqtor.optimize.minimize

::: inspeqtor.optimize.stochastic_minimize

::: inspeqtor.optimize.fit_gaussian_process

::: inspeqtor.optimize.predict_with_gaussian_process

::: inspeqtor.optimize.predict_mean_and_std

::: inspeqtor.optimize.expected_improvement

::: inspeqtor.optimize.BayesOptState

::: inspeqtor.optimize.init_opt_state

::: inspeqtor.optimize.suggest_next_candidates

::: inspeqtor.optimize.add_observations
